==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/VictorOpsConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class VictorOpsConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigBuilder>{
  public VictorOpsConfigBuilder() {
    this(false);
  }
  public VictorOpsConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new VictorOpsConfig(), validationEnabled);
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new VictorOpsConfig(), validationEnabled);
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig instance) {
    this(fluent, instance, false);
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiKey(instance.getApiKey()); 
    fluent.withApiUrl(instance.getApiUrl()); 
    fluent.withCustomFields(instance.getCustomFields()); 
    fluent.withEntityDisplayName(instance.getEntityDisplayName()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessageType(instance.getMessageType()); 
    fluent.withMonitoringTool(instance.getMonitoringTool()); 
    fluent.withRoutingKey(instance.getRoutingKey()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withStateMessage(instance.getStateMessage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig instance) {
    this(instance,false);
  }
  public VictorOpsConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiKey(instance.getApiKey()); 
    this.withApiUrl(instance.getApiUrl()); 
    this.withCustomFields(instance.getCustomFields()); 
    this.withEntityDisplayName(instance.getEntityDisplayName()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessageType(instance.getMessageType()); 
    this.withMonitoringTool(instance.getMonitoringTool()); 
    this.withRoutingKey(instance.getRoutingKey()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withStateMessage(instance.getStateMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.VictorOpsConfig build() {
    VictorOpsConfig buildable = new VictorOpsConfig(fluent.getApiKey(),fluent.getApiUrl(),fluent.getCustomFields(),fluent.getEntityDisplayName(),fluent.getHttpConfig(),fluent.getMessageType(),fluent.getMonitoringTool(),fluent.getRoutingKey(),fluent.getSendResolved(),fluent.getStateMessage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VictorOpsConfigBuilder that = (VictorOpsConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/VictorOpsConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VictorOpsConfigBuilder extends VictorOpsConfigFluentImpl<VictorOpsConfigBuilder> implements VisitableBuilder<VictorOpsConfig,VictorOpsConfigBuilder>{
  public VictorOpsConfigBuilder() {
    this(false);
  }
  public VictorOpsConfigBuilder(Boolean validationEnabled) {
    this(new VictorOpsConfig(), validationEnabled);
  }
  public VictorOpsConfigBuilder(VictorOpsConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public VictorOpsConfigBuilder(VictorOpsConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VictorOpsConfig(), validationEnabled);
  }
  public VictorOpsConfigBuilder(VictorOpsConfigFluent<?> fluent,VictorOpsConfig instance) {
    this(fluent, instance, false);
  }
  public VictorOpsConfigBuilder(VictorOpsConfigFluent<?> fluent,VictorOpsConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiKey(instance.getApiKey()); 
    fluent.withApiUrl(instance.getApiUrl()); 
    fluent.withCustomFields(instance.getCustomFields()); 
    fluent.withEntityDisplayName(instance.getEntityDisplayName()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessageType(instance.getMessageType()); 
    fluent.withMonitoringTool(instance.getMonitoringTool()); 
    fluent.withRoutingKey(instance.getRoutingKey()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withStateMessage(instance.getStateMessage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public VictorOpsConfigBuilder(VictorOpsConfig instance) {
    this(instance,false);
  }
  public VictorOpsConfigBuilder(VictorOpsConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiKey(instance.getApiKey()); 
    this.withApiUrl(instance.getApiUrl()); 
    this.withCustomFields(instance.getCustomFields()); 
    this.withEntityDisplayName(instance.getEntityDisplayName()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessageType(instance.getMessageType()); 
    this.withMonitoringTool(instance.getMonitoringTool()); 
    this.withRoutingKey(instance.getRoutingKey()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withStateMessage(instance.getStateMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  VictorOpsConfigFluent<?> fluent;
  Boolean validationEnabled;
  public VictorOpsConfig build() {
    VictorOpsConfig buildable = new VictorOpsConfig(fluent.getApiKey(),fluent.getApiUrl(),fluent.getCustomFields(),fluent.getEntityDisplayName(),fluent.getHttpConfig(),fluent.getMessageType(),fluent.getMonitoringTool(),fluent.getRoutingKey(),fluent.getSendResolved(),fluent.getStateMessage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
